# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Latest](https://github.com/NordicSemiconductor/svada)

## [v1.0.1](https://github.com/nordicsemiconductor/svada/tree/v1.0.1)

### Fixed

* Fixed an issue with raw register values not accounting for reset values of bits without a field (#3)
* Fixed an issue with nested register numbering (#4)

## [v1.0.0](https://github.com/nordicsemiconductor/svada/tree/v1.0.0)

* Initial release.
